--[==[
If you want to change these to something else, like in-jokes for your guild,
write a small addon like this.  Lines with * are crucial and should not be
changed from how they're shown here.

      Interface/AddOns/YourMod/YourMod.toc:
        =================================
        ## Interface: xxxxx
        ## Title: Ouro Loot For My Guild
      * ## RequiredDeps: Ouro_Loot
      * ## LoadOnDemand: 1
      * ## LoadWith: Ouro_Loot
    
        main.lua
        =================================

Then replace specific entries like this:

      Interface/AddOns/YourMod/main.lua:
        =================================
      * local ouroloot = LibStub("AceAddon-3.0"):GetAddon("Ouro Loot")
    
        ouroloot.instance_abbrev["The Bastion of Twilight"] =
            [[Steve Said He Would /gquit If We Make Him Go Here Ever Again]]

        ouroloot.boss_abbrev["Omnotron Defense System"] =
            [[Jim Will Facetank The Slimes Now]]

        ouroloot:Print [[Tweaked stuff for mah guildies!]]
        =================================

This lets you update Ouro Loot with a new version (which would overwrite
this file) without losing any of your changes.
]==]

local addon = select(2,...)
if addon.NOLOAD then return end

--[==[
The index is the universal InstanceMapID value, which can be looked up here:
   http://wowpedia.org/InstanceMapID
You can also use the official English localized name, which was the only
available method in the past.  Note that these names are case-sensistive.
]==]
addon.instance_abbrev = {
	-------- WoD
	--[] = "", -- Highmaul
	--[] = "BRF", -- Blackrock Foundry

	-------- MoP
	[1008] = "MV", -- Mogu'shan Vaults
	[1009] = "HoF", -- Heart of Fear
	[996] = "ToES", -- Terrace of Endless Spring
	[1098] = "ToT", -- Throne of Thunder
	[1136] = "SoO", -- Siege of Orgrimmar

	-------- Cata
	[757] = "BH", -- Baradin Hold
	[671] = "BoT", -- The Bastion of Twilight
	[669] = "BWD", -- Blackwing Descent
	[754] = "To4W", -- Throne of the Four Winds
	-- surely these names are short enough already...?
	--[720] = "F", -- Firelands
	--[967] = "DS", -- Dragon Soul

	-------- WotLK
	[631] = "ICC", -- Icecrown Citadel
	[650] = "ToC", -- Trial of the Champion (dungeon)
	[649] = "ToC", -- Trial of the Crusader (raid)
	[624] = "VoA", -- Vault of Archavon
}

-- Currently indexed by "boss name" values, as generated by whatever boss mod
-- is in use; see specific boss mod handling code to see how they get it.
addon.boss_abbrev = {
	-------- WoD

	-------- MoP
	-- MV
	["Will of the Emperor"] = "Talk to the Open Hand",

	-------- Cata
	-- BoT
	["Halfus Wyrmbreaker"] = "Halfass Wyrmbreaker",
	["Valiona & Theralion"] = "Wonder Twins! Form of: Loot",
	-- BWD
	["Magmaw"] = "Earwig",
	["Omnotron Defense System"] = "Nomnomtron Defense System",
	["Chimaeron"] = "k'eye-MAIR-on",
	["Atramedes"] = "at-ruh-MEE-deez",
	["Nefarian's End"] = "Nef II:  Electric Boogaloo",
	-- To4W
	["Al'Akir"] = "Big Al",
	-- Firelands
	["Shannox"] = "Shnox",
	["Lord Rhyolith"] = "LEFT, LEFT, LEFT RIGHT LEFT",  -- left my wife and 49 kids, an old grey mare and a peanut stand
	["Alysrazor"] = "Steppin' Razor",  -- how many people have read Neuromancer, hmmmm
	["Majordomo Staghelm"] = "Mojododo",
	-- Dragon Soul
	["Morchok"] = "Porkchop",
	["Warlord Zon'ozz"] = "Warlord Beach Ball",
	["Yor'sahj the Unsleeping"] = "Yosimite Sam the Unsleeping",
	["Hagara the Stormbinder"] = "Hands Across America",
	["Ultraxion"] = "ul-TRAX-ee-on",

	-------- WotLK
	-- ToC
	["Northrend Beasts"] = "Animal House",
	["Lord Jaraxxus"] = "latest DIAF demon",
	["Faction Champions"] = "Alliance Clusterfuck",
	["Valkyr Twins"] = "Salt'N'Pepa",
	["Val'kyr Twins"] = "Salt'N'Pepa",
	["Anub'arak"] = "Whack-a-Spider",
	-- ICC
	["Lady Deathwhisper"] = "Lady Won't-Stop-Yammering",
	["Gunship"] = "Rocket Shirt Over the Side of the Damn Boat",
	["Gunship Battle"] = "Rocket Shirt Over the Side of the Damn Boat",
	["Deathbringer Saurfang"] = "Deathbringer Sauerkraut",
	["Professor Putricide"] = "Professor Farnsworth",
	["Valithria Dreamwalker"] = "Dreeeeaaamweaaaaaverrrr",
}

addon.FILES_LOADED = addon.FILES_LOADED + 1
-- vim:noet
